Loaders
=======

The MuonDataLib can be used to write muon nexus v2 (histogram) files that are compatable with Wimda.
At present, the files do not include the sample logs.

Currently MuonDataLib can load data from:

- Muon nexus v2 (histogram) files

